@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2016  Ruby-GNOME2 Project Team
+# Copyright (C) 2014-2018  Ruby-GNOME2 Project Team
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -83,6 +83,7 @@ module Gtk
       require "gtk3/about-dialog"
       require "gtk3/action"
       require "gtk3/action-group"
+      require "gtk3/application"
       require "gtk3/binding-set"
       require "gtk3/border"
       require "gtk3/box"
@@ -98,6 +99,7 @@ module Gtk
       require "gtk3/container"
       require "gtk3/css-provider"
       require "gtk3/dialog"
+      require "gtk3/entry"
       require "gtk3/entry-buffer"
       require "gtk3/file-chooser-dialog"
       require "gtk3/font-chooser-dialog"
@@ -179,7 +181,9 @@ module Gtk
         method_name = rubyish_method_name(info)
         define_method(info, widget_class, method_name)
       when /\Adrag_/
-        method_name = rubyish_method_name(info, :prefix => "drag_")
+        method_name = rubyish_method_name(info,
+                                          :prefix => "drag_",
+                                          :n_in_args_offset => -1)
         define_method(info, Gdk::DragContext, method_name)
       when /\Abinding_/
         # Ignore because singleton methods are defined.
